==> igloo_0_1_2.zip: igloo_0_1_2/igloo/language/1/barnraiser_01/nlt_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'nlt_view.lang.php');


//section titles
$lang['hdr_sent'] = 						"sent";


//HEADER
$lang['hdr_newsletter'] = 						"create your newsletter";


//SUBMIT BUTTONS
$lang['sub_newsletter'] = 						"send";


//BODY TEXT
$lang['txt_intro'] =							"You can send an email newsletter to people who have chosen to receive emails using this newsletter publisher.";
$lang['txt_emails_sent'] =						"newsletters sent";
$lang['txt_subject'] =							"subject";
$lang['txt_subject_txt'] =						"Barnraiser newsletter!";
$lang['txt_message'] =							"message";
$lang['txt_message_help'] =						"Newsletters should be short and to the point with links to longer articles. The members first name will automatically be inserted into the newsletter anywhere the text 'FIRSTNAME' appears.";
$lang['txt_message_txt'] =						"Hi FIRSTNAME,\n\nMessage body here.";
$lang['txt_language'] =							"language";
$lang['txt_language_help'] =					"The newsletter will only be sent to members with the following preferred language.";
$lang['txt_to'] =								"to";
$lang['txt_to_help'] =							"Please note, if sending to invitees select ALL languages and do not use FIRSTNAME as we do not know their language or name.";
$lang['txt_newsletter_intro'] = 				"If you type FIRSTNAME in a newsletter FIRSTNAME will be replaced with the members first name.";
$lang['txt_to_type1'] =							"members";
$lang['txt_to_type2'] =							"pending members";
$lang['txt_to_type3'] =							"invitees";
$lang['txt_croncomplete'] =						"Your newsletter has been processed and will be sent out soon.";

$lang['txt_header_1'] = 						"1. Newsletter";
$lang['txt_header_2'] = 						"2. Publishing";
$lang['txt_header_3'] = 						"3. Send";
$lang['txt_send_intro'] = 						"Send your newsletter.";

?>

==> igloo_0_1_3.zip: igloo_0_1_3/igloo/language/1/barnraiser_01/nlt_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'nlt_view.lang.php');


//section titles
$lang['hdr_sent'] = 						"sent";


//HEADER
$lang['hdr_newsletter'] = 						"create your newsletter";


//SUBMIT BUTTONS
$lang['sub_newsletter'] = 						"send";


//BODY TEXT
$lang['txt_intro'] =							"You can send an email newsletter to people who have chosen to receive emails using this newsletter publisher.";
$lang['txt_subject'] =							"subject";
$lang['txt_subject_txt'] =						"my_node newsletter!";
$lang['txt_message'] =							"message";
$lang['txt_message_help'] =						"Newsletters should be short and to the point with links to longer articles. The members first name will automatically be inserted into the newsletter anywhere the text 'FIRSTNAME' appears.";
$lang['txt_message_txt'] =						"Hi FIRSTNAME,\n\nMessage body here.";
$lang['txt_language'] =							"language";
$lang['txt_language_help'] =					"The newsletter will only be sent to members with the following preferred language.";
$lang['txt_to'] =								"to";
$lang['txt_to_help'] =							"Please note, if sending to invitees select ALL languages and do not use FIRSTNAME as we do not know their language or name.";
$lang['txt_newsletter_intro'] = 				"If you type FIRSTNAME in a newsletter FIRSTNAME will be replaced with the members first name.";
$lang['txt_to_type1'] =							"all registered users";
$lang['txt_to_type2'] =							"pending users";
$lang['txt_to_type3'] =							"invitees";
$lang['txt_send_role'] =						"send to role";
$lang['txt_send_type'] =						"or type";
$lang['txt_header_1'] = 						"1. Newsletter";
$lang['txt_header_2'] = 						"2. Publishing";
$lang['txt_header_3'] = 						"3. Send";
$lang['txt_send_intro'] = 						"Send your newsletter.";

?>
